<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../about.ui" line="47"/>
        <source>Packet Sender</source>
        <translation>Packet Sender</translation>
    </message>
    <message>
        <location filename="../about.ui" line="136"/>
        <source>Written by Dan Nagle and published by NagleCode, LLC</source>
        <translation>Écrit par Dan Nagle et publié par NagleCode, LLC</translation>
    </message>
    <message>
        <location filename="../about.ui" line="165"/>
        <source>TextLabel</source>
        <translation>Étiquette de texte</translation>
    </message>
    <message>
        <location filename="../about.ui" line="185"/>
        <source>PacketSender.com</source>
        <translation>PacketSender.com</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="26"/>
        <source>
Commit Hash: </source>
        <translation>
Engagez le Hash: </translation>
    </message>
    <message>
        <location filename="../about.cpp" line="31"/>
        <source>About Packet Sender</source>
        <translation>À propos de Packet Sender</translation>
    </message>
</context>
<context>
    <name>BruceThePoodle</name>
    <message>
        <location filename="../brucethepoodle.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../brucethepoodle.cpp" line="29"/>
        <source>Bruce The Poodle!</source>
        <translation>Bruce le caniche!</translation>
    </message>
</context>
<context>
    <name>CloudUI</name>
    <message>
        <location filename="../cloudui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="28"/>
        <source>Account</source>
        <translation>Compte</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="49"/>
        <source>Packet Sender Cloud</source>
        <translation>Cloud Packet Sender</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="73"/>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="91"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="112"/>
        <source>Confirm Password</source>
        <translation>Confirmer le mot de passe</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="131"/>
        <source>Remember Login</source>
        <translation>Mémoriser l&apos;ouverture de session</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="140"/>
        <location filename="../cloudui.cpp" line="466"/>
        <source>Login</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="150"/>
        <location filename="../cloudui.cpp" line="465"/>
        <source>Create a new account.</source>
        <translation>Créer un nouveau compte.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="187"/>
        <source>Privacy</source>
        <translation>Confidentialité</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="194"/>
        <source>Terms</source>
        <translation>Termes</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="214"/>
        <source>cloud.packetsender.com/help</source>
        <translation>cloud.packetsender.com/help</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="228"/>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="239"/>
        <source>Import From URL</source>
        <translation>Importer depuis URL</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="248"/>
        <location filename="../cloudui.ui" line="372"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="268"/>
        <source>View URL</source>
        <translation>Afficher l&apos;URL</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="283"/>
        <source>Delete Packet Set</source>
        <translation>Supprimer un ensemble de paquets</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="290"/>
        <source>Import Packet Set</source>
        <translation>Importer un ensemble de paquets</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="307"/>
        <source>Save / Share</source>
        <translation>Sauvegarder / Partager</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="313"/>
        <source>You are sharing.</source>
        <translation>Vous êtes en train de partager.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="322"/>
        <source>Packet Set Name</source>
        <translation>Nom de l&apos;ensemble de paquets</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="336"/>
        <source>Public Path</source>
        <translation>Chemin public</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="359"/>
        <source>Make Public</source>
        <translation>Rendre public</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="401"/>
        <source>Save to Packet Sender Cloud</source>
        <translation>Sauvegarder dans le Cloud du Packet Sender</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="83"/>
        <source>Cloud</source>
        <translation>Cloud</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source>Saving </source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source> packet set to cloud</source>
        <translation> Paquet réglé sur le Cloud</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="470"/>
        <source>Login instead.</source>
        <translation>Connectez-vous plutôt.</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="471"/>
        <source>Sign-up</source>
        <translation>S&apos;inscrire</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="528"/>
        <source>Delete Set</source>
        <translation>Supprimer l&apos;ensemble</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source>Delete the set </source>
        <translation>Supprimer l&apos;ensemble </translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source> from cloud?</source>
        <translation>du cloud?</translation>
    </message>
</context>
<context>
    <name>IrisAndMarigold</name>
    <message>
        <location filename="../irisandmarigold.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
</context>
<context>
    <name>LanguageChooser</name>
    <message>
        <location filename="../languagechooser.ui" line="14"/>
        <source>Choose Language</source>
        <translation>Choisissez la langue</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="46"/>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="79"/>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="115"/>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="151"/>
        <source>Français</source>
        <translation>Français</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="187"/>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="206"/>
        <source>OK / Aceptar</source>
        <translation>OK / Aceptar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="48"/>
        <source>Packet Name</source>
        <translation>Nom du paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Request</source>
        <translation>Demande</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>URL path</source>
        <translation>Chemin de l&apos;URL</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Generate Data</source>
        <translation>Générer les données</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>ASCII representation</source>
        <translation>Représentation ASCII</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Load File</source>
        <translation>Charger le fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>HEX</source>
        <translation>HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>HEX representation</source>
        <translation>Représentation HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>IPv4, IPv6, DNS Lookup</source>
        <translation>IPv4, IPv6, recherche DNS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>1 to 65535</source>
        <translation>1 à 65535</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Resend Delay</source>
        <translation>Délai de renvoi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>0.0/blank off</source>
        <translation>0.0/suppression des données</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>TCP</source>
        <translation>TCP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>UDP</source>
        <translation>UDP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>SSL</source>
        <translation>SSL</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>HTTP Get</source>
        <translation>HTTP Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>HTTP Post</source>
        <translation>HTTP Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>HTTPS Get</source>
        <translation>HTTP Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>HTTPS Post</source>
        <translation>HTTP Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.cpp" line="1074"/>
        <location filename="../mainwindow.cpp" line="1732"/>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Search Saved Packets...</source>
        <translation>Rechercher les paquets sauvegardés...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="360"/>
        <source>Generate Panel!</source>
        <translation>Générer le panneau!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Delete Saved Packet</source>
        <translation>Supprimer le paquet sauvegardé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>Persistent TCP</source>
        <translation>TCP persistant</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>Clear Log</source>
        <translation>Effacer le registre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Log Traffic</source>
        <translation>Trafic de registres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Save Log</source>
        <translation>Sauvegarder le registre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Save Traffic Packet</source>
        <translation>Sauvegarder le paquet de trafic</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>Copy to Clipboard</source>
        <translation>Copier vers le presse-papier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>&amp;Multicast</source>
        <translation>&amp;Multicast</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>Panels</source>
        <translation>Panneaux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>E&amp;xit</source>
        <translation>&amp;Sortir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="581"/>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>&amp;About</source>
        <translation>&amp;A propos de</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>&amp;Import Database</source>
        <translation>&amp;Importation de la base de données</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>&amp;Export Database</source>
        <translation>&amp;Exportation de la base de données</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Persistent Connection</source>
        <translation>Connexion persistante</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="622"/>
        <source>&amp;Subnet Calculator</source>
        <translation>&amp;Calculateur de sous-réseau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>D&amp;onate (Thank You!)</source>
        <translation>&amp;Faites un don (Merci !)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="636"/>
        <source>Documentation</source>
        <translation>Documentation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Documentation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="650"/>
        <source>Export To Cloud</source>
        <translation>Exporter vers le cloud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>&amp;Cloud Save and Share</source>
        <translation>&amp;Sauvegarde et partage dans le Cloud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>&amp;Join/Leave IPv4</source>
        <translation>&amp;Rejoindre/quitter IPv4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Android App</source>
        <translation>Android App</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>iOS App</source>
        <translation>iOS App</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Follow on Twitter</source>
        <translation>Suivez-nous sur Twitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <source>Connect on LinkedIn</source>
        <translation>Connectez-vous sur LinkedIn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>Intense &amp;Traffic Generator</source>
        <translation>Intense &amp;Générateur de trafic</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>Forums</source>
        <translation>Forums</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="727"/>
        <source>Load Starter Panel</source>
        <translation>charge le panneau de démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Empty Panel Project</source>
        <translation>Projet de panneaux vides</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="741"/>
        <source>Wake-On-LAN / Magic Packet</source>
        <translation>Wake-On-LAN</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Updates.</source>
        <translation>Mises à jour.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>There is a new Packet Sender available.

Download?</source>
        <translation>Il y a un nouveau Packet Sender disponible.

Télécharger?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Let Packet Sender check for updates weekly?</source>
        <translation>Laisser Packet Sender vérifier les mises à jour chaque semaine?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Packet Sender Updated!</source>
        <translation>Mise à jour de Packet Sender!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Updated to </source>
        <translation>Mis à jour à </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>!

Would you like to read the release notes?</source>
        <translation>!

Voulez-vous lire les notes de lancement?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="735"/>
        <source>Clear Log </source>
        <translation>Effacer le registre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <location filename="../mainwindow.cpp" line="782"/>
        <location filename="../mainwindow.cpp" line="803"/>
        <source> Ports</source>
        <translation> Ports</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="766"/>
        <source>UDP Server Disabled</source>
        <translation>Serveur UDP désactivé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <source>TCP Server Disabled</source>
        <translation>Serveur TCP désactivé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1030"/>
        <location filename="../mainwindow.cpp" line="1271"/>
        <source>Multicast detected.</source>
        <translation>Multicast détecté.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1034"/>
        <source>Do you wish to join the multicast group?</source>
        <translation>Souhaitez-vous rejoindre le groupe multicast?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1050"/>
        <location filename="../mainwindow.cpp" line="1293"/>
        <source>Broadcast with responses!</source>
        <translation>Diffusez avec des réponses!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <source>You are sending a broadcast packet with responses enabled.

This could cause traffic flooding. Continue?</source>
        <translation>Vous envoyez un paquet de diffusion avec des réponses activées.

Cela pourrait provoquer une inondation du trafic. Continuer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <location filename="../mainwindow.cpp" line="1068"/>
        <location filename="../mainwindow.cpp" line="1333"/>
        <location filename="../mainwindow.cpp" line="1939"/>
        <source>Resending</source>
        <translation>Renvoyer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="788"/>
        <source>SSL Server Disabled</source>
        <translation>Serveur SSL désactivé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>bytes</source>
        <translation>octets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1101"/>
        <source>Name cannot be blank.</source>
        <translation>Le nom ne peut pas être vide.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1105"/>
        <source>Name is empty.</source>
        <translation>Le nom est vide.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1155"/>
        <source>This computer does not support SSL.

Expected SSL:</source>
        <translation>Cet ordinateur ne prend pas en charge le protocole SSL.

SSL attendu :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1159"/>
        <source>No SSL Library.</source>
        <translation>Pas de bibliothèque SSL.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1212"/>
        <source>Address cannot be blank.</source>
        <translation>L&apos;adresse ne peut pas être vide.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1216"/>
        <source>Address is empty.</source>
        <translation>L&apos;adresse est vide.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <source>Port cannot be blank/zero.</source>
        <translation>Le port ne peut pas être vide/zéro.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1231"/>
        <source>Port is zero.</source>
        <translation>Le port est zéro.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1245"/>
        <source>IPv6?</source>
        <translation>IPv6?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1249"/>
        <source>Enable IPv6 support?</source>
        <translation>Activer le support IPv6?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1275"/>
        <source>Join UDP multicast group?</source>
        <translation>Rejoindre le groupe multicast UDP?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1313"/>
        <source>Resend TCP with persistent connections!</source>
        <translation>Renvoyer le TCP avec des connexions persistantes!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1317"/>
        <source>You are resending a TCP packet with persistent connections. The UI could spawn numerous windows! 

Uncheck persistent connection? (Recommended)</source>
        <translation>Vous renvoyez un paquet TCP avec des connexions persistantes. L&apos;interface utilisateur pourrait créer de nombreuses fenêtres !

Désactivez la connexion persistante ? (Recommandé)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1352"/>
        <location filename="../mainwindow.cpp" line="2002"/>
        <source>No packets selected.</source>
        <translation>Aucun paquet sélectionné.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1356"/>
        <source>Select a packet.</source>
        <translation>Sélectionnez un paquet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1395"/>
        <source>Invalid Address / DNS failed</source>
        <translation>Adresse non valide / échec du DNS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1418"/>
        <source>Invalid Port</source>
        <translation>Port invalide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1862"/>
        <source>Clear Log (0)</source>
        <translation>Effacer le registre (0)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1881"/>
        <source>Save Packet</source>
        <translation>Enregistrer le paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1882"/>
        <source>Packet name:</source>
        <translation>Nom du paquet:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2006"/>
        <source>Clipboard unchanged.</source>
        <translation>Presse-papiers inchangé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2067"/>
        <source>Save Traffic Log</source>
        <translation>Enregistrer le registre du trafic</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>log (*.log)</source>
        <translation>registre (*.log)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>TIME</source>
        <translation>Temp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From IP</source>
        <translation>De l&apos;IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From Port</source>
        <translation>Du port</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>To IP</source>
        <translation>Vers IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>To Port</source>
        <translation>Vers IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2262"/>
        <source>Import JSON</source>
        <translation>Importer JSON</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2264"/>
        <location filename="../mainwindow.cpp" line="2331"/>
        <source>JSON db (*.json)</source>
        <translation>JSON db (*.json)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source>Found </source>
        <translation>Trouvé </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source> packets!</source>
        <translation> paquets!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source>Import </source>
        <translation>Importer </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source> packets?

Packet Sender will overwrite packets with the same name.</source>
        <translation>paquets?

Le Packet Sender écrasera les paquets portant le même nom.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2295"/>
        <location filename="../mainwindow.cpp" line="2316"/>
        <location filename="../mainwindow.cpp" line="2432"/>
        <location filename="../mainwindow.cpp" line="2453"/>
        <source>Import Cancelled</source>
        <translation>Importation annulée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2303"/>
        <source>Import Finished</source>
        <translation>Importation terminée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2309"/>
        <location filename="../mainwindow.cpp" line="2446"/>
        <source>Not a database</source>
        <translation>Pas une base de données</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2313"/>
        <location filename="../mainwindow.cpp" line="2450"/>
        <source>Found no packets in this file. It may not be a Packet Sender export</source>
        <translation>Je n&apos;ai trouvé aucun paquet dans ce fichier. Il se peut que ce ne soit pas une exportation de Packet Sender</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2330"/>
        <source>Save JSON</source>
        <translation>Sauvegarder JSON</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2485"/>
        <source>Export: </source>
        <translation>Exporter: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2356"/>
        <source>Could not save</source>
        <translation>Pas pu sauvegarder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2360"/>
        <source>Could not open </source>
        <translation>Pas pu ouvrir </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2406"/>
        <location filename="../mainwindow.cpp" line="2531"/>
        <source>Import File</source>
        <translation>Importer le fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2408"/>
        <location filename="../mainwindow.cpp" line="2463"/>
        <source>INI db (*.ini)</source>
        <translation>INI db (*.ini)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2462"/>
        <source>Save File</source>
        <translation>Sauvegarder le ficher</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2533"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2557"/>
        <source>Max size exceeded!</source>
        <translation>Taille maximale dépassée!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2561"/>
        <source>The HEX field supports up to 10,922 bytes. The data has been truncated.</source>
        <translation>Le fichier HEX peut supporter jusqu&apos;à 10 922 octets. Les données ont été tronquées.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source>Loading </source>
        <translation>Chargement </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source> bytes</source>
        <translation> octets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2801"/>
        <source>Invalid MAC Address.</source>
        <translation>Adresse MAC invalide</translation>
    </message>
</context>
<context>
    <name>MulticastSetup</name>
    <message>
        <location filename="../multicastsetup.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="22"/>
        <source>IP Multicast Address</source>
        <translation>Adresse IP multicast</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="29"/>
        <source>Join</source>
        <translation>Rejoignez</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="54"/>
        <source>Leave All Groups</source>
        <translation>Quitter tous les groupes</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="15"/>
        <source>IPv4 Multicast Setup (Experimental)</source>
        <translation>Configuration du multicast IPv4 (expérimental)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="31"/>
        <source>There are no bound UDP ports</source>
        <translation>Il n&apos;y a pas de ports UDP liés</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="34"/>
        <source>UDP socket bound to </source>
        <translation>Prise UDP liée à</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="36"/>
        <source> will join the multicast group</source>
        <translation> rejoindra le groupe multicast</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="59"/>
        <source>Not Multicast.</source>
        <translation>Pas de multicast.</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="63"/>
        <source>IP must be an IPv4 multicast address.
(224.0.0.0 to 239.255.255.255)</source>
        <translation>IP doit être une adresse de multicast IPv4.
(224.0.0.0 à 239.255.255.255)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="74"/>
        <source>IPv4-only.</source>
        <translation>IPv4 seulement.</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="78"/>
        <source>Packet Sender supports multicast when binded to IPv4. 
Turn off IPv6 and switch to IPv4 mode?</source>
        <translation>Packet Sender supporte le multicast lorsqu&apos;il est lié à IPv4.
Désactiver IPv6 et passer en mode IPv4?</translation>
    </message>
</context>
<context>
    <name>PacketLogModel</name>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source>Data portion is </source>
        <translation>La portion de données est </translation>
    </message>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source> bytes</source>
        <translation> octes</translation>
    </message>
</context>
<context>
    <name>PacketNetwork</name>
    <message>
        <location filename="../packetnetwork.cpp" line="246"/>
        <source>Port bind error.</source>
        <translation>Erreur de liaison de port.</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="250"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT], which is less than 1024. 

Privileged ports requires running Packet Sender with admin-level / root permissions.</source>
        <translation>Packet Sender a tenté (et échoué) de se connecter au port [PORT], qui est inférieur à 1024.

Les ports privilégiés nécessitent l&apos;exécution de Packet Sender avec des autorisations de niveau administrateur / root.</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="251"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT].

 - Are you running multiple instances? 

 - Trying to bind to a missing custom IP?</source>
        <translation>Packet Sender a tenté (et échoué) de se connecter au port [PORT].

- Exécutez-vous plusieurs instances?

- Vous essayez de vous lier à une IP personnalisée manquante?</translation>
    </message>
</context>
<context>
    <name>PanelGenerator</name>
    <message>
        <location filename="../panelgenerator.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="56"/>
        <location filename="../panelgenerator.ui" line="69"/>
        <location filename="../panelgenerator.ui" line="82"/>
        <location filename="../panelgenerator.ui" line="95"/>
        <location filename="../panelgenerator.ui" line="108"/>
        <location filename="../panelgenerator.ui" line="121"/>
        <location filename="../panelgenerator.ui" line="134"/>
        <location filename="../panelgenerator.ui" line="147"/>
        <location filename="../panelgenerator.ui" line="160"/>
        <source>PushButton</source>
        <translation>Bouton-poussoir</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="183"/>
        <source>&amp;File</source>
        <translation>&amp;Ficher</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="192"/>
        <source>&amp;Export</source>
        <translation>&amp;Exporter</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="203"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="209"/>
        <source>S&amp;ettings</source>
        <translation>&amp;paramètres</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="223"/>
        <source>&amp;Save</source>
        <translation>&amp;Sauvegarder</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="226"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="231"/>
        <source>Save &amp;As...</source>
        <translation>Sauvegarder &amp;As...</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="236"/>
        <source>&amp;Import Panels File</source>
        <translation>&amp;Importer le fichier de panneaux</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="239"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="244"/>
        <source>Portable &amp;Windows Package</source>
        <translation>Portable &amp;Paquet Windows</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="247"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="252"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Documentation</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="255"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="260"/>
        <source>Panel Name</source>
        <translation>Nom du panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="265"/>
        <source>Panel ID</source>
        <translation>ID du panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="273"/>
        <source>Starter Panel:</source>
        <translation>Panneau de démarrage :</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="278"/>
        <location filename="../panelgenerator.cpp" line="48"/>
        <source>Delete Panel</source>
        <translation>Supprimer le panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="283"/>
        <source>&amp;Panels File</source>
        <translation>&amp;Fichier de panneaux</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="288"/>
        <source>Portable &amp;macOS Package</source>
        <translation>Portable &amp;paquet macOS</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="293"/>
        <source>Portable Linux Package</source>
        <translation>Paquet Linux portable</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="298"/>
        <source>&amp;New Panel</source>
        <translation>&amp;Nouveau panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="301"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="40"/>
        <source>Panels</source>
        <translation>Panneaux</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="47"/>
        <source>Load Panel</source>
        <translation>Chargement du panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="52"/>
        <location filename="../panelgenerator.cpp" line="364"/>
        <source>Viewing</source>
        <translation>Visualiser</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="135"/>
        <source>URL or File</source>
        <translation>URL ou fichier</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="136"/>
        <source>URL or File:</source>
        <translation>URL ou fichier</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="155"/>
        <source>Link text</source>
        <translation>Lier le texte</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="156"/>
        <source>Link text:</source>
        <translation>Lier le texte:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="321"/>
        <source>Confirm delete.</source>
        <translation>Confirmez la suppression.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="325"/>
        <source>Delete </source>
        <translation>Supprimer </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="331"/>
        <source>Deleting </source>
        <translation>Supprimer </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="339"/>
        <source>Panel </source>
        <translation>panneau </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="341"/>
        <source>Set Panel Name: </source>
        <translation>Définir le nom du panneau: </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="342"/>
        <source>Set Panel ID: </source>
        <translation>Définir l&apos;ID du panneau: </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="346"/>
        <source>Packet Sender Panel: New Panel</source>
        <translation>Panneau Packet Sender: Nouveau panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="347"/>
        <source>Set Panel Name: New Panel</source>
        <translation>Définir le nom du panneau: Nouveau panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="348"/>
        <source>Set Panel ID: New Panel</source>
        <translation>Définir l&apos;ID du panneau:Nouveau panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="354"/>
        <source>Starter Panel: Yes</source>
        <translation>Panneau de démarrage: Oui</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="356"/>
        <source>Starter Panel: No</source>
        <translation>Panneau de démarrage : Non</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="359"/>
        <source>Editing</source>
        <translation>Editer</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="436"/>
        <source>Button </source>
        <translation>Bouton </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="443"/>
        <source>(Button will be deleted)</source>
        <translation>(Le bouton sera supprimé)</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="453"/>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="460"/>
        <source>Script is empty</source>
        <translation>Le script est vide</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="522"/>
        <location filename="../panelgenerator.cpp" line="527"/>
        <source>New Button</source>
        <translation>Nouveau bouton</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="692"/>
        <source>Nothing to do...</source>
        <translation>Rien à faire...</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="694"/>
        <source>Executing </source>
        <translation>Exécution </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="699"/>
        <source>Unknown Command</source>
        <translation>Commandement inconnu</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="769"/>
        <source>Transition Panel</source>
        <translation>Panel de transition</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>Tranisition to Panel &quot;</source>
        <translation>Transition vers le panel &quot;</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>&quot;?
This panel has not been saved. You may lose changes.</source>
        <translation>&quot; ?
Ce panneau n&apos;a pas été sauvegardé. Vous risquez de perdre les modifications.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="785"/>
        <source>Not loading panel</source>
        <translation>Pas de chargement du panneau</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="789"/>
        <source>Not loading panel in edit mode</source>
        <translation>Pas de chargement du panneau en mode édition</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="905"/>
        <source>Change URL</source>
        <translation>Changer l&apos;URL</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="906"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="913"/>
        <source>Delete link</source>
        <translation>Supprimer le lien</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="917"/>
        <source>Delete URL link?
</source>
        <translation>Supprimer le lien URL?
</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="928"/>
        <source>Change Text</source>
        <translation>Changer le texte</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="929"/>
        <source>text:</source>
        <translation>texte:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="990"/>
        <source>Panels File</source>
        <translation>Fichier de panneaux</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="992"/>
        <source>*.panels</source>
        <translation>*.panels</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1029"/>
        <source>Unknown File</source>
        <translation>Fichier inconnu</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1032"/>
        <source>This does not seem to be a valid PS Panels file</source>
        <translation>Il semble que ce ne soit pas un fichier valide de Panneaux PS.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source>Found </source>
        <translation>Trouvé </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <source> packets. Saving overwrites duplicate names.

Continue packet import?</source>
        <translation> paquets. L&apos;enregistrement écrase les noms en double.

Continuer l&apos;importation de paquets ?</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source> panels. Ovewrite dpulicated IDs?

Selecting No will generate new IDs and append.</source>
        <translation> panneaux. Écraser les identifiants déjà existants ?

En sélectionnant Non, de nouveaux identifiants seront générés et les données seront ajoutées à la liste de la base de données.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1143"/>
        <source>Coming soon.</source>
        <translation>Bientôt.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1160"/>
        <source>Change Name</source>
        <translation>Changer de nom</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1161"/>
        <location filename="../panelgenerator.cpp" line="1209"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1177"/>
        <source>Change ID</source>
        <translation>Changer l&apos;ID</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1178"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1208"/>
        <source>New Name</source>
        <translation>Nouveau nom</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1243"/>
        <source>Save PS Panels</source>
        <translation>Sauvegarder les panneaux PS</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1244"/>
        <source>panels (*.panels)</source>
        <translation>panneaux (*.panels)</translation>
    </message>
</context>
<context>
    <name>PersistentConnection</name>
    <message>
        <location filename="../persistentconnection.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="26"/>
        <source>Waiting...</source>
        <translation>Attendre...</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="40"/>
        <source>Load</source>
        <translation>Chargement</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="47"/>
        <source>Search Packets...</source>
        <translation>Fouiller les paquets...</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="61"/>
        <source>Raw</source>
        <translation>Brut</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="71"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="84"/>
        <source>ASCII. Press Enter to Send.</source>
        <translation>ASCII. Appuyez sur la touche Entrée pour envoyer.</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="94"/>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="104"/>
        <source>Append \r</source>
        <translation>Annexer \r</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="114"/>
        <location filename="../persistentconnection.cpp" line="468"/>
        <source>Send File</source>
        <translation>Envoyer le fichier</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="158"/>
        <source>Clear Log</source>
        <translation>Effacer le registre</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="165"/>
        <source>To Clipboard</source>
        <translation>Vers le presse-papier</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="185"/>
        <source>Resending(1)</source>
        <translation>Renvoyer(1)</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="154"/>
        <location filename="../persistentconnection.cpp" line="156"/>
        <source>You:</source>
        <translation>Toi:</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="470"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="511"/>
        <source>Copied</source>
        <translation>Copié</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="512"/>
        <source>Output sent to your clipboard</source>
        <translation>Résultat envoyé à votre presse-papiers</translation>
    </message>
</context>
<context>
    <name>PersistentHTTP</name>
    <message>
        <location filename="../persistenthttp.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="44"/>
        <source>Copy Code</source>
        <translation>Copier le code</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="64"/>
        <source>.html View/Edit</source>
        <translation>.html Afficher/Editer</translation>
    </message>
</context>
<context>
    <name>PostDataGen</name>
    <message>
        <location filename="../postdatagen.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="22"/>
        <source>Key</source>
        <translation>Clé</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="32"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="42"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="51"/>
        <source>Params</source>
        <translation>Params</translation>
    </message>
    <message>
        <location filename="../postdatagen.cpp" line="30"/>
        <source>Data Generator</source>
        <translation>Générateur de données</translation>
    </message>
</context>
<context>
    <name>PreviewFilter</name>
    <message>
        <location filename="../mainwindow.cpp" line="2726"/>
        <source>Multi-line editor</source>
        <translation>Éditeur multi-lignes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2732"/>
        <source>Update</source>
        <translation>Mise à jour</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2733"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../packet.cpp" line="266"/>
        <location filename="../settings.cpp" line="44"/>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="267"/>
        <source>Send &lt;b&gt;</source>
        <translation>Envoyer &lt;b&gt;</translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="627"/>
        <source>Received an invalid MAC address</source>
        <translation>Reçu une adresse MAC invalide</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="47"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="50"/>
        <source>Resend</source>
        <translation>Renvoyer</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="53"/>
        <source>To Address</source>
        <translation>À l&apos;adresse</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="56"/>
        <source>To Port</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="59"/>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="62"/>
        <source>Request Path</source>
        <translation>Demande de chemin</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="65"/>
        <source>Time</source>
        <translation>Temp</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="68"/>
        <source>From IP</source>
        <translation>de l&apos;IP</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="71"/>
        <source>From Port</source>
        <translation>Du port</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="74"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="24"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="30"/>
        <source>Basic</source>
        <translation>Base</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="36"/>
        <source>Enable UDP Servers</source>
        <translation>Activer les serveurs UDP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="45"/>
        <source>UDP Server Ports (comma-separated, 0 for random)</source>
        <translation>Ports du serveur UDP (séparés par des virgules, 0 pour randomiser)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="52"/>
        <location filename="../settings.ui" line="77"/>
        <location filename="../settings.ui" line="102"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="61"/>
        <source>Enable TCP Servers</source>
        <translation>Activer les serveurs TCP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="70"/>
        <source>TCP Server Port (comma-separated, 0 for random)</source>
        <translation>Ports du serveur TCP (séparés par des virgules, 0 pour randomiser)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="86"/>
        <source>Enable SSL/TLS Servers</source>
        <translation>Activer les serveurs SSL/TLS</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="111"/>
        <source>Set the server ports to 0 if you want to run multiple Packet Sender instances.</source>
        <translation>Définissez les ports du serveur sur 0 si vous souhaitez exécuter plusieurs instances de Packet Sender.</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="125"/>
        <source>Translate macros when sending</source>
        <translation>Traduire les macros lors de l&apos;envoi</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="132"/>
        <source>Send a basic response with macro support</source>
        <translation>Envoyer une réponse de base avec le support macro</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="141"/>
        <source>Response Data</source>
        <translation>Données de réponse</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="155"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="169"/>
        <location filename="../settings.ui" line="771"/>
        <location filename="../settings.ui" line="833"/>
        <location filename="../settings.ui" line="867"/>
        <location filename="../settings.ui" line="908"/>
        <location filename="../settings.ui" line="941"/>
        <source>HEX</source>
        <translation>HEX</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="197"/>
        <source>Additional UDP/TCP/SSL Settings</source>
        <translation>Paramètres UDP/TCP/SSL supplémentaires</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="205"/>
        <source>IPv4 Only</source>
        <translation>IPv4 seulement</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="218"/>
        <source>IPv6 Only</source>
        <translation>IPv6 seulement</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="230"/>
        <source>Bind This:</source>
        <translation>Liez ça:</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="240"/>
        <source>Your IP</source>
        <translation>Votre adresse IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="253"/>
        <source>Multi-Send Delay (sec)</source>
        <translation>Délai d&apos;envoi multiple (sec)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="260"/>
        <source>0.0 for off</source>
        <translation>0,0 pour la désactivation</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="271"/>
        <source>Cancel Resending after # packets</source>
        <translation>Annuler Renvoi après # paquets</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="278"/>
        <source>0 for off</source>
        <translation>0 pour la désactivation</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="287"/>
        <source>Attempt Receive Before Send</source>
        <translation>Tenter de recevoir avant d&apos;envoyer</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="95"/>
        <source>SSL Server Port (comma-separated, 0 for random)</source>
        <translation>Ports du serveur SSL (séparés par des virgules, 0 pour randomiser)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="294"/>
        <source>500 ms delay after connect (slow devices)</source>
        <translation>500 ms de retard après la connexion (appareils lents)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="301"/>
        <source>Persistent TCP Connections</source>
        <translation>Connexions TCP persistantes</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="308"/>
        <source>Resolve DNS during input (old method)</source>
        <translation>Résoudre le DNS pendant la saisie (ancienne méthode)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="315"/>
        <source>Ignore SSL Errors (Wrong host, expired, self-signed, etc)</source>
        <translation>Ignorer les erreurs SSL (mauvais hôte, expiré, auto-signé, etc.)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="328"/>
        <source>SSL Server may use an internal snake oil cert</source>
        <translation>Le serveur SSL peut utiliser un certificat interne de type snake oil.</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="337"/>
        <source>SSL CA Certificates</source>
        <translation>Certificats SSL CA</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="344"/>
        <source>Path from where to load the CA certificats (leave empty for defaults)</source>
        <translation>Chemin à partir duquel charger les certificats CA (laissez vide pour les valeurs par défaut)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="351"/>
        <location filename="../settings.ui" line="376"/>
        <location filename="../settings.ui" line="401"/>
        <source>Browse</source>
        <translation>Naviguer</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="362"/>
        <source>SSL Local Certificate</source>
        <translation>Certificat local SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="369"/>
        <source>File path for the client side local certificate</source>
        <translation>Chemin du fichier pour le certificat local côté client</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="387"/>
        <source>SSL Private Key</source>
        <translation>Clé privée SSL</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="394"/>
        <source>File path for the client side private key</source>
        <translation>Chemin du fichier pour la clé privée côté client</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="430"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="436"/>
        <source>Automatically adjust ContentType when sending XML or JSON</source>
        <translation>Ajustement automatique du type de contenu lors de l&apos;envoi de XML ou JSON</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="458"/>
        <source>Generate Auth Header</source>
        <translation>Générer l&apos;en-tête d&apos;authentification</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="469"/>
        <location filename="../settings.cpp" line="975"/>
        <source>Host</source>
        <translation>Hôte</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="479"/>
        <source>Username/ClientID</source>
        <translation>Nom d&apos;utilisateur/ID client</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="489"/>
        <source>Password/AccessCode</source>
        <translation>Mot de passe/Code d&apos;accès</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="499"/>
        <location filename="../settings.cpp" line="1046"/>
        <source>HTTP Header</source>
        <translation>En-tête HTTP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="530"/>
        <source>Delete Header</source>
        <translation>Supprimer l&apos;en-tête</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="540"/>
        <source>Display</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="548"/>
        <source>Saved Packet Display Order (Drag and Drop)</source>
        <translation>Ordre d&apos;affichage des paquets sauvegardés (déplacer et déposer)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="555"/>
        <location filename="../settings.ui" line="583"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="560"/>
        <location filename="../settings.ui" line="588"/>
        <source>To IP</source>
        <translation>A IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="565"/>
        <location filename="../settings.ui" line="593"/>
        <source>From IP</source>
        <translation>de l&apos;IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="576"/>
        <source>Traffic Log Display Order (Drag and Drop)</source>
        <translation>Ordre d&apos;affichage du registre du trafic (&quot;déplacer et déposer&quot;)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="601"/>
        <source>Use Default Order</source>
        <translation>Utiliser l&apos;ordre par défaut</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="626"/>
        <source>Miscellaneous</source>
        <translation>Divers</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="632"/>
        <source>Use Dark Theme (requires restart)</source>
        <translation>Utiliser le thème sombre (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="641"/>
        <source>Language (Requires Restart)</source>
        <translation>Langue (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="650"/>
        <source>Copy to Clipboard button uses raw data</source>
        <translation>Le bouton &quot;Copier dans le presse-papiers&quot; utilise les données brutes</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="657"/>
        <source>Rolling 100-entry traffic log</source>
        <translation>Registre de bord roulant de 100 entrées</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="664"/>
        <source>Restore previous session</source>
        <translation>Restaurer la session précédente</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="671"/>
        <source>Periodically check for updates</source>
        <translation>Vérifier périodiquement les mises à jour</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="678"/>
        <source>Use ellipsis [...] for long data entries (helps performance)</source>
        <translation>Utilisez les points de suspension [...] pour les longues entrées de données (améliore les performances).</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="685"/>
        <source>Auto-Launch Starter Panel</source>
        <translation>Panneau de démarrage automatique</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="722"/>
        <source>Smart Responses</source>
        <translation>Réponses intelligentes</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="730"/>
        <source>Send a Smart Response with Macro Support</source>
        <translation>Envoyez une réponse intelligente grâce au support macro</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="758"/>
        <source>Response 5</source>
        <translation>Réponse 5</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="766"/>
        <location filename="../settings.ui" line="828"/>
        <location filename="../settings.ui" line="862"/>
        <location filename="../settings.ui" line="903"/>
        <location filename="../settings.ui" line="936"/>
        <source>Mixed ASCII</source>
        <translation>ASCII mélangé</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="779"/>
        <location filename="../settings.ui" line="844"/>
        <location filename="../settings.ui" line="882"/>
        <location filename="../settings.ui" line="895"/>
        <location filename="../settings.ui" line="928"/>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="786"/>
        <source>Response 4</source>
        <translation>Réponse 4</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="793"/>
        <source>If Packet data equals</source>
        <translation>Si les données du paquet sont égales</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="800"/>
        <source>Reply with</source>
        <translation>Répondre avec</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="807"/>
        <source>Encoding</source>
        <translation>Encodage</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="814"/>
        <source>Response 1</source>
        <translation>Réponse 1</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="854"/>
        <source>Response 2</source>
        <translation>Réponse  2</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="875"/>
        <source>Response 3</source>
        <translation>Réponse  3</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="963"/>
        <source>Available macros: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</source>
        <translation>Macros disponibles: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="970"/>
        <source>Packet Sender will swap macro with a real value before sending</source>
        <translation>Packet Sender échangera la macro avec une valeur réelle avant de l&apos;envoyer.</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="981"/>
        <source>{{DATE}} format (Requires Restart)</source>
        <translation>{{DATE}} format (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="998"/>
        <location filename="../settings.ui" line="1039"/>
        <source>Example</source>
        <translation>Exemple</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1022"/>
        <source>{{TIME}} format (Requires Restart)</source>
        <translation>{TIME} format (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1083"/>
        <source>Online Documentation</source>
        <translation>Documents en ligne</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="103"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="359"/>
        <source>Bad IP.</source>
        <translation>Mauvaise IP</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="363"/>
        <source>Packet Sender cannot bind invalid IP </source>
        <translation>Packet Sender ne peut pas lier l&apos;IP invalide</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="377"/>
        <source>TCP and SSL non-zero port conflict.</source>
        <translation>Conflit de ports non nuls entre TCP et SSL.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="381"/>
        <source>Packet Sender cannot bind TCP and SSL to the same port.</source>
        <translation>Packet Sender ne peut pas lier TCP et SSL au même port.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="726"/>
        <source>Open Directory</source>
        <translation>Répertoire ouvert</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Choose Cert</source>
        <translation>Choisissez un certificat</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Certs (*.pem)</source>
        <translation>Certificats (*.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Choose Key</source>
        <translation>Choisissez une clé</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Keys (*.key, *.pem)</source>
        <translation>Clés (*.key, *.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1044"/>
        <source>Key</source>
        <translation>Clé</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1045"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1040"/>
        <source>UN/ClientID</source>
        <translation>UN/IDClient</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1041"/>
        <source>PW/Access</source>
        <translation>MP/Accès</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1042"/>
        <source>HTTP Auth Header</source>
        <translation>En-tête d&apos;authentification HTTP</translation>
    </message>
</context>
<context>
    <name>SubnetCalc</name>
    <message>
        <location filename="../subnetcalc.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="26"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="33"/>
        <source>IPv4 address</source>
        <translation>Adresse IPv4</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="44"/>
        <source>Subnet</source>
        <translation>Sous-réseau</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="51"/>
        <source>Dotted or number of bits </source>
        <translation>En pointillé ou nombre de bits </translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="66"/>
        <source>Start</source>
        <translation>Démarrage</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="76"/>
        <source>Calculated Start..</source>
        <translation>Démarrage calculé..</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="87"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="97"/>
        <source>Calculated End...</source>
        <translation>Fin calculée...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="108"/>
        <source>Broadcast</source>
        <translation>Diffusion</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="118"/>
        <source>Broadcast...</source>
        <translation>Diffusion...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="133"/>
        <source>Within subnet check</source>
        <translation>Contrôle à l&apos;intérieur du sous-réseau</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="140"/>
        <source>IP Address...</source>
        <translation>L&apos;adresse IP...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="156"/>
        <source>Subnet Check Result...</source>
        <translation>Résultat de la vérification du sous-réseau...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="168"/>
        <source>Results log...</source>
        <translation>Registre des résultats...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="177"/>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="24"/>
        <source>IPv4 Subnet Calculator</source>
        <translation>Calculateur de sous-réseau IPv4</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="26"/>
        <source>Your non-loopback addresses: 

</source>
        <translation>Vos adresses non-loopback:

</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="263"/>
        <source>Within </source>
        <translation>au sein de </translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="273"/>
        <source>No entries in subnet.</source>
        <translation>Pas d&apos;entrées dans le sous-réseau.</translation>
    </message>
</context>
<context>
    <name>UDPFlooding</name>
    <message>
        <location filename="../udpflooding.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="24"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="38"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="54"/>
        <source>Ascii</source>
        <translation>Ascii</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="76"/>
        <source>Delay (ms)</source>
        <translation>Délai (ms)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="86"/>
        <source>Speed (MB/s)</source>
        <translation>Vitesse (MB/s)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="101"/>
        <source>0 or blank is no delay or max speed</source>
        <translation>0 ou blanc n&apos;est pas un retard ou une vitesse max</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="110"/>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="117"/>
        <source>Stop</source>
        <translation>Arrêtez</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="139"/>
        <source>Waiting to send...</source>
        <translation>En attente d&apos;envoi...</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="25"/>
        <source>UDP Traffic Generator (Experimental)</source>
        <translation>Générateur de trafic UDP (expérimental)</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="76"/>
        <location filename="../udpflooding.cpp" line="81"/>
        <source>Invalid</source>
        <translation>Invalide</translation>
    </message>
</context>
<context>
    <name>WakeOnLAN</name>
    <message>
        <location filename="../wakeonlan.ui" line="14"/>
        <source>Wake-On-LAN</source>
        <translation>Wake-On-LAN</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="22"/>
        <source>Target MAC</source>
        <translation>MAC cible</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="29"/>
        <source>01:23:45:67:89:ab</source>
        <translation>01:23:45:67:89:ab</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="36"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="59"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="68"/>
        <source>9</source>
        <translation>9</translation>
    </message>
</context>
</TS>
